@@ -1,17 +1,21 @@
 #' Walk the Abstract Syntax Tree (AST) of an R Expression
 #'
 #' @param expr R \link[base]{expression}.
-#' @param atomic,name,call,pairlist single-argument function that takes an atomic, name, call and pairlist expression, respectively. Have to return a valid R expression.
+#' @param atomic,name,call,pairlist single-argument function that takes an
+#'        atomic, name, call and pairlist expression, respectively. Have to
+#'        return a valid R expression.
 #' @param name single-argument function that takes a name expression.
 #' @param call single-argument function that takes a call expression.
 #' @param pairlist single-argument function that takes a pairlist expression.
-#' @param substitute If TRUE, \code{expr} is \code{\link[base]{substitute}()}:ed.
+#' @param substitute If TRUE, \code{expr} is
+#'        \code{\link[base]{substitute}()}:ed.
 #'
 #' @return R \link[base]{expression}.
 #'
 #' @export
 #' @keywords programming internal
-walkAST <- function(expr, atomic=NULL, name=NULL, call=NULL, pairlist=NULL, substitute=FALSE) {
+walkAST <- function(expr, atomic = NULL, name = NULL, call = NULL,
+                    pairlist = NULL, substitute = FALSE) {
   if (substitute) expr <- substitute(expr)
 
   if (is.atomic(expr)) {
@@ -21,9 +25,10 @@ walkAST <- function(expr, atomic=NULL, name=NULL, call=NULL, pairlist=NULL, subs
   } else if (is.call(expr)) {
 ##    message("call")
     for (cc in seq_along(expr)) {
-      ## AD HOC: The following is needed to handle x[,1]. /HB 2016-09-06
+      ## AD HOC: The following is needed to handle x[, 1]. /HB 2016-09-06
       if (is.name(expr[[cc]]) && expr[[cc]] == "") next
-      e <- walkAST(expr[[cc]], atomic=atomic, name=name, call=call, pairlist=pairlist, substitute=FALSE)
+      e <- walkAST(expr[[cc]], atomic = atomic, name = name, call = call,
+                   pairlist = pairlist, substitute = FALSE)
       if (is.null(e)) {
         expr[cc] <- list(NULL)
       } else {
@@ -36,7 +41,8 @@ walkAST <- function(expr, atomic=NULL, name=NULL, call=NULL, pairlist=NULL, subs
     for (pp in seq_along(expr)) {
       ## AD HOC: The following is needed to handle '...'. /HB 2016-09-06
       if (is.name(expr[[pp]]) && expr[[pp]] == "") next
-      e <- walkAST(expr[[pp]], atomic=atomic, name=name, call=call, pairlist=pairlist, substitute=FALSE)
+      e <- walkAST(expr[[pp]], atomic = atomic, name = name, call = call,
+                   pairlist = pairlist, substitute = FALSE)
       if (is.null(e)) {
         expr[pp] <- list(NULL)
       } else {
@@ -48,14 +54,23 @@ walkAST <- function(expr, atomic=NULL, name=NULL, call=NULL, pairlist=NULL, subs
     ## https://stat.ethz.ch/pipermail/r-devel/2016-October/073263.html
     ## /HB 2016-10-12
     expr <- as.pairlist(expr)
+  } else if (typeof(expr) %in% c("builtin", "closure", "special")) {
+    ## Nothing to do
+    ## FIXME: ... or can closures and specials be "walked"? /HB 2017-03-21
+    return(expr)
   } else {
-    stop("Cannot walk expression. Unknown object type ", sQuote(typeof(expr)), call.=FALSE)
+    stop("Cannot walk expression. Unknown object type ",
+         sQuote(typeof(expr)), call. = FALSE)
   }
 
   ## Assert that the tweak functions return a valid object
   if (!missing(expr)) {
-    stopifnot(is.atomic(expr) || is.name(expr) || is.call(expr) || is.pairlist(expr))
+    stopifnot(is.atomic(expr) ||
+              is.name(expr) ||
+              is.call(expr) ||
+              is.pairlist(expr) ||
+              typeof(expr) %in% c("builtin", "closure", "special"))
   }
-  
+
   expr
 } ## walkAST()
